#############################################################
# Project:   Garage Monitor
# Date:      1-16-2020
# Author:    Jim Abraham
# File Name: garage.py  (Main program)

# Software: Python 3 Rev: W1.01_abe_11620
# Hardware: Raspberry PI 3B+, DS18B20, door remote.
#
#############################################################
import RPi.GPIO as GPIO
from datetime import datetime
from temp_module import *
from gdoor_module import *
from file_manager_module import *

#------------------------------------------------------------
# Pin Definitions
#------------------------------------------------------------
# LEDS: (GPO)
#------------------------------------------------------------
Door_is_Down_LED = 5
Operate_Door_LED = 6
#Recieve_Data_LED = 17
Door_is_Up_LED = 22
WDT_LED = 23            # Controlled in separate script.
Operate_Light_LED = 26
#Send_Data_LED = 27

#------------------------------------------------------------
# OUTPUTS: (GPO)
#------------------------------------------------------------
Operate_Door_CMD = 24   # wired to spare remote
Door_Light_CMD = 25     # wired to spare remote

#------------------------------------------------------------
# INPUTS (GPI)
#------------------------------------------------------------
#Garage_Temp = 4     # DS18B20 temp sensor 
Door_Position = 16  # 1=Open, 0=Closed

#------------------------------------------------------------
# Suppress Warnings
#------------------------------------------------------------
GPIO.setwarnings(False)

#------------------------------------------------------------
# Use GPIO pin numbering
#------------------------------------------------------------
GPIO.setmode(GPIO.BCM)

#------------------------------------------------------------
# Set Inputs
#------------------------------------------------------------
GPIO.setup(Door_Position,GPIO.IN)

#------------------------------------------------------------
# Set Outputs
#------------------------------------------------------------
GPIO.setup(Door_is_Down_LED,GPIO.OUT)
GPIO.setup(Operate_Door_LED,GPIO.OUT)
#GPIO.setup(Recieve_Data_LED,GPIO.OUT)
GPIO.setup(Door_is_Up_LED,GPIO.OUT)
GPIO.setup(Operate_Light_LED,GPIO.OUT)
#GPIO.setup(Send_Data_LED,GPIO.OUT)
GPIO.setup(Operate_Door_CMD,GPIO.OUT)
GPIO.setup(Door_Light_CMD,GPIO.OUT)
#GPIO.setup(WDT_LED,GPIO.OUT)

#------------------------------------------------------------
# Initialize Outputs
#------------------------------------------------------------
GPIO.output(Door_is_Down_LED,0)
GPIO.output(Operate_Door_LED,0)
#GPIO.output(Recieve_Data_LED,0)
GPIO.output(Door_is_Up_LED,0)
GPIO.output(Operate_Light_LED,0)
#GPIO.output(Send_Data_LED,0)
GPIO.output(Operate_Door_CMD,0)
GPIO.output(Door_Light_CMD,0)
#GPIO.output(WDT_LED,0)

#GPIO.add_event_detect(Door_Position, event, callback = my_callback, bouncetime = timeinmilliseconds)

#------------------------------------------------------------
# Define Global Variables
#------------------------------------------------------------
global mloop
global dt_string, debug_print

#------------------------------------------------------------
# Initialize Global Variables
#------------------------------------------------------------
dt_string=""
mloop=0
debug_print=0    # 1=print 0=no print

#------------------------------------------------------------
def reboot(dt_string):
#------------------------------------------------------------
    if (debug_print==1): print(dt_string, " System Reboot")
    message = dt_string + " System Reboot"
    Write_sys_file(message)
          
#------------------------------------------------------------
def Write_sys_file(message):
#------------------------------------------------------------
     f = open("/home/pi/projects/garage/system_logs/sys.log",'a')
     f.write(message)
     f.write("\n")
     f.close()
     
#---------------------------------------------
# Call Routines for startup
#---------------------------------------------
now = datetime.now()
dt_string = now.strftime("%b-%d _ %-I:%M %p") #"%m/%d/%Y %-I:%M:%S %p")
reboot(dt_string)

Clear_Web_Site_Commands_File()

#/\/\/\/\/\/\/\/\/\/\/\/\/\/\/\/\/\/\/\/\/\/\/\/\/\/\/\/\/\/\/
# Main Routine
#/\/\/\/\/\/\/\/\/\/\/\/\/\/\/\/\/\/\/\/\/\/\/\/\/\/\/\/\/\/\/
try:
    while(True):
        # Main loop counter (0.1 sec)
        mloop=mloop+1

        # Get Current date and Time
        now = datetime.now()
        dt_string = now.strftime("%b-%d_%-I:%M%p") #"%m/%d/%Y %-I:%M:%S %p")
        #File_Management()
        
        # Check Door Position
        Check_Door_Position(dt_string)
        # Check Door Operate Command
        Check_Door_Operate_Command(dt_string)
        # Check Door Light Command
        Check_Door_Light_Command(dt_string)
        
        # Get Temp Reading
        if (mloop>=10):
            read_temp()
            Write_temp_file(dt_string)
            mloop=0
            
        time.sleep(.1)

finally:
        GPIO.cleanup() # this ensures a clean exit  

#/\/\/\/\/\/\/\/\/\/\/\/\/\/\/\/\/\/\/\/\/\/\/\/\/\/\/\/\/\/\/
